@@ -1,10 +1,11 @@
 
 class Operation:
 
-    def __init__(self, uuid: str, product_uuid: str, pose: dict, description: str = "", _type: str = ''):
+    def __init__(self, uuid: str, product_uuid: str, pose: dict, automated: bool = False, description: str = "", _type: str = ''):
         assert type(uuid) == str
         assert type(product_uuid) == str
         assert type(pose) == dict
+        assert type(automated) == bool
         assert type(description) == str
         for key in ['x', 'y', 'z', 'rx', 'ry', 'rz']:
             assert key in pose, f"The following must be in pose-dict: {key}. Pose: {pose}"
@@ -14,6 +15,7 @@ class Operation:
         self.uuid = uuid
         self.product_uuid = product_uuid
         self.pose = pose
+        self.automated = automated
         self.description = description
 
     def __eq__(self, other: object) -> bool:
@@ -21,6 +23,7 @@ class Operation:
             return other.uuid == self.uuid \
                    and other.product_uuid == self.product_uuid \
                    and other.pose == self.pose \
+                   and other.automated == self.automated \
                    and other.description == self.description
         return False
 
@@ -28,4 +31,5 @@ class Operation:
         return not self.__eq__(other)
 
     def __repr__(self):
-        return f"<uuid={self.uuid},product_uuid={self.product_uuid},pose={self.pose},description={self.description}>"
+        return f"<uuid={self.uuid},product_uuid={self.product_uuid},pose={self.pose},automated={self.automated}," \
+               f"description={self.description}>"
