@@ -15,6 +15,9 @@ class Script:
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
+    def __repr__(self):
+        return f"Script<filename={self.filename}, path={self.path}>"
+
 
 class WaypointConfig:
 
@@ -31,3 +34,7 @@ class WaypointConfig:
 
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
+
+    def __repr__(self):
+        return f"WaypointConfig<" \
+               f"show_waypoints={self.show_waypoints}, show_current_waypoint={self.show_current_waypoint}>"
